AppError

Struct AppError 

pub struct AppError<D = ()> { /* private fields */ }
A reference-counted untyped error that can be created from any error type.

Named AppError as it’s mostly useful in application code that don’t care about the errors specifically, and instead only care to show them to users.

Implementations

Source

impl<D> AppError<D>

pub fn new<E>(err: &E) -> Self
where E: ?Sized + StdError, D: Default,

Creates a new app error from an error

pub fn msg(msg: &'static str) -> Self
where D: Default,

Creates a new app error from a message

pub fn fmt<M>(msg: M) -> Self
where M: Display, D: Default,

Creates a new app error from a formattable message

pub fn context(&self, msg: &'static str) -> Self
where D: Default,

Adds context to this error

pub fn with_context<F, M>(&self, with_msg: F) -> Self
where F: FnOnce() -> M, M: Display, D: Default,

Adds context to this error

pub fn from_multiple<Errs>(errs: Errs) -> Self
where Errs: IntoIterator<Item = Self>,

Creates a new app error from multiple errors

pub fn from_multiple_std<'a, Errs, E>(errs: Errs) -> Self
where Errs: IntoIterator<Item = &'a E>, E: ?Sized + StdError + 'a, D: Default,

Creates a new app error from multiple standard errors

pub fn flatten(self) -> Self
where D: Clone,

Flattens all multiple errors recursively.

pub fn as_std_error(&self) -> &(dyn StdError + 'static)
where D: Debug + 'static,

Returns this type as a std::error::Error

pub fn into_std_error(self) -> Arc<dyn StdError + Send + Sync + 'static>
where D: Debug + Send + Sync + 'static,

Converts this type as into a std::error::Error

pub fn pretty(&self) -> PrettyDisplay<'_, D>

Returns an object that can be used for a pretty display of this error

pub fn data_iter(&self) -> DataIter<'_, D>

Returns an iterator over all data in this error, recursively.

Order

No order is guaranteed and it may change at any time.

Source

impl<D> AppError<D>

pub fn new_with_data<E>(err: &E, data: D) -> Self
where E: ?Sized + StdError, D: Clone,

Creates a new app error from an error and data.

data will be applied to all sources of err

pub fn msg_with_data(msg: &'static str, data: D) -> Self

Creates a new app error from a message

pub fn fmt_with_data<M>(msg: M, data: D) -> Self
where M: Display,

Creates a new app error from a formatted message

pub fn context_with_data(&self, msg: &'static str, data: D) -> Self

Adds context to this error

pub fn with_context_with_data<F, M>(&self, with_msg: F, data: D) -> Self
where F: Fn() -> M, M: Display,

Adds context to this error